@@ -1,5 +1,7 @@
 """
-Main interface for iot-data service client
+Type annotations for iot-data service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
 
 Usage::
 
@@ -48,7 +50,8 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [IoTDataPlane.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
     """
 
     meta: ClientMeta
@@ -56,14 +59,16 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can-paginate)
         """
 
     def delete_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> DeleteThingShadowResponseTypeDef:
         """
-        [Client.delete_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete-thing-shadow)
         """
 
     def generate_presigned_url(
@@ -74,31 +79,36 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate-presigned-url)
         """
 
     def get_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> GetThingShadowResponseTypeDef:
         """
-        [Client.get_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get-thing-shadow)
         """
 
     def list_named_shadows_for_thing(
         self, thingName: str, nextToken: str = None, pageSize: int = None
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
-        [Client.list_named_shadows_for_thing documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list-named-shadows-for-thing)
         """
 
     def publish(self, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None) -> None:
         """
-        [Client.publish documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
         """
 
     def update_thing_shadow(
         self, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
     ) -> UpdateThingShadowResponseTypeDef:
         """
-        [Client.update_thing_shadow documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update-thing-shadow)
         """
